/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.edge;


import java.util.Comparator;

public class Global {
	
	private static final double DBL_EPSILON = 2.2204460492503131e-16;

	private static final double M_ZERO_ANGLE_COSINE = 1.0e-9;
	private static final double M_TOL_VECTORS_PARALLEL = 1e-9;
	private static final double M_HIGH_ACCURACY_TOL = DBL_EPSILON * 5;
	private static final double M_TOL_POINTS_EQUAL = 1e-3;
	
	private Global() {
	}
	
	public static double getTolPointsEquals() {
		return M_TOL_POINTS_EQUAL;
	}

	public static double getHighAccuracyTolerance() {
		return M_HIGH_ACCURACY_TOL;
	}

	public static Comparator<Double> getDoubleTolCompare(double epsilon) {
		return (v1, v2) -> {
			double dif = v1 - v2;
			if (Math.abs(dif) < epsilon) {
				return 0;
			}
			return Double.compare(v1, v2);
		};
	}

	public static double getZeroAngleCosine() { return M_ZERO_ANGLE_COSINE; }

	public static double getTolVectorsParallel() {
		return M_TOL_VECTORS_PARALLEL;
	}

}
